DROP DATABASE IF EXISTS Auth4c;

CREATE DATABASE Auth4c;

CREATE TABLE Auth4c.Platform
(
    Platform CHAR(4) NOT NULL,
    Description VARCHAR(32) NOT NULL,
    CONSTRAINT PK_Platform PRIMARY KEY
    (
        Platform
    )
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE Auth4c.AuthenticationLibrary
(
    AuthenticationLibrary INT NOT NULL,
    Description VARCHAR(32) NOT NULL,
    AuthenticationTokenDisposition CHAR(1) NOT NULL,
    UserTools CHAR(1) NOT NULL,
    CONSTRAINT PK_AuthenticationLibrary PRIMARY KEY
    (
        AuthenticationLibrary
    )
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE Auth4c.SharedObject
(
    Platform CHAR(4) NOT NULL,
    AuthenticationLibrary INT NOT NULL,
    SharedObject VARCHAR(128) NOT NULL,
    CONSTRAINT PK_SharedObject PRIMARY KEY
    (
        AuthenticationLibrary,
        Platform
    ),
    CONSTRAINT FK_SharedObject_1 FOREIGN KEY
    (
        AuthenticationLibrary
    )
    REFERENCES Auth4c.AuthenticationLibrary
    (
        AuthenticationLibrary
    ),
    CONSTRAINT FK_SharedObject_2 FOREIGN KEY
    (
        Platform
    )
    REFERENCES Auth4c.Platform
    (
        Platform
    )
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE Auth4c.Product
(
    Product INT NOT NULL,
    Description VARCHAR(32) NOT NULL,
    CONSTRAINT PK_Product PRIMARY KEY
    (
        Product
    )
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE Auth4c.ProductRole
(
    Product INT NOT NULL,
    Role INT NOT NULL,
    Description VARCHAR(64) NOT NULL,
    Status TINYINT NOT NULL,
    CONSTRAINT PK_ProductRole PRIMARY KEY
    (
        Product,
        Role
    ),
    CONSTRAINT FK_ProductRole_1 FOREIGN KEY
    (
        Product
    )
    REFERENCES Auth4c.Product
    (
        Product
    )
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE Auth4c.ProductPermission
(
    Product INT NOT NULL,
    Permission INT NOT NULL,
    Description VARCHAR(64) NOT NULL,
    Status TINYINT NOT NULL,
    CONSTRAINT PK_ProductPermission PRIMARY KEY
    (
        Product,
        Permission
    ),
    CONSTRAINT FK_ProductPermission_1 FOREIGN KEY
    (
        Product
    )
    REFERENCES Auth4c.Product
    (
        Product
    )
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE Auth4c.ProductRolePermission
(
    Product INT NOT NULL,
    Role INT NOT NULL,
    Permission INT NOT NULL,
    Status TINYINT NOT NULL,
    CONSTRAINT PK_ProductRolePermission PRIMARY KEY
    (
        Product,
        Role,
        Permission
    ),
    CONSTRAINT FK_ProductRolePermission_1 FOREIGN KEY
    (
        Product,
        Role
    )
    REFERENCES Auth4c.ProductRole
    (
        Product,
        Role
    ),
    CONSTRAINT FK_ProductRolePermission_2 FOREIGN KEY
    (
        Product,
        Permission
    )
    REFERENCES Auth4c.ProductPermission
    (
        Product,
        Permission
    )
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE Auth4c.Customer
(
    Customer VARCHAR(8) NOT NULL,
    Name VARCHAR(128) NOT NULL,
    CONSTRAINT PK_Customer PRIMARY KEY
    (
        Customer
    )
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE Auth4c.CustomerProductRole
(
    Customer VARCHAR(8) NOT NULL,
    Product INT NOT NULL,
    Role INT NOT NULL,
    Status TINYINT NOT NULL,
    CONSTRAINT PK_CustomerProductRole PRIMARY KEY
    (
        Customer,
        Product,
        Role
    ),
    CONSTRAINT FK_CustomerProductRole_1 FOREIGN KEY
    (
        Customer
    )
    REFERENCES Auth4c.Customer
    (
        Customer
    ),
    CONSTRAINT FK_CustomerProductRole_2 FOREIGN KEY
    (
        Product,
        Role
    )
    REFERENCES Auth4c.ProductRole
    (
        Product,
        Role
    )
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE Auth4c.CustomerProductPermission
(
    Customer VARCHAR(8) NOT NULL,
    Product INT NOT NULL,
    Permission INT NOT NULL,
    Status TINYINT NOT NULL,
    CONSTRAINT PK_CustomerProductPermission PRIMARY KEY
    (
        Customer,
        Product,
        Permission
    ),
    CONSTRAINT FK_CustomerProductPermission_1 FOREIGN KEY
    (
        Customer
    )
    REFERENCES Auth4c.Customer
    (
        Customer
    ),
    CONSTRAINT FK_CustomerProductPermission_2 FOREIGN KEY
    (
        Product,
        Permission
    )
    REFERENCES Auth4c.ProductPermission
    (
        Product,
        Permission
    )
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE Auth4c.Team
(
    Team INT NOT NULL,
    Customer VARCHAR(8) NOT NULL,
    Name VARCHAR(64) NOT NULL,
    CONSTRAINT PK_Team PRIMARY KEY
    (
        Team
    ),
    CONSTRAINT FK_Team_1 FOREIGN KEY
    (
        Customer
    )
    REFERENCES Auth4c.Customer
    (
        Customer
    )
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE Auth4c.Domain
(
    Domain VARCHAR(32) NOT NULL,
    Description VARCHAR(128) NOT NULL,
    Customer VARCHAR(8) NOT NULL,
    AuthenticationLibrary INT NOT NULL,
    UserTools CHAR(1) NOT NULL,
    CONSTRAINT PK_Domain PRIMARY KEY
    (
        Domain
    ),
    CONSTRAINT FK_Domain_1 FOREIGN KEY
    (
        Customer
    )
    REFERENCES Auth4c.Customer
    (
        Customer
    ),
    CONSTRAINT FK_Domain_2 FOREIGN KEY
    (
        AuthenticationLibrary
    )
    REFERENCES Auth4c.AuthenticationLibrary
    (
        AuthenticationLibrary
    )
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE Auth4c.Profile
(
    Profile VARCHAR(32) NOT NULL,
    IsDefault CHAR(1) NOT NULL,
    CONSTRAINT PK_Profile PRIMARY KEY
    (
        Profile
    )
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE Auth4c.ProfileHost
(
    Profile VARCHAR(32) NOT NULL,
    Host VARCHAR(128) NOT NULL,
    CONSTRAINT PK_ProfileHost PRIMARY KEY
    (
        Profile,
        Host
    ),
    CONSTRAINT FK_ProfileHost_1 FOREIGN KEY
    (
        Profile
    )
    REFERENCES Auth4c.Profile
    (
        Profile
    )
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE Auth4c.TeamMap
(
    Domain VARCHAR(32) NOT NULL,
    AlienGroup VARCHAR(128) NOT NULL,
    AlienGroupLeadGroup VARCHAR(128),
    Team INT NOT NULL,
    CONSTRAINT PK_TeamMap PRIMARY KEY
    (
        Domain,
        Team
    ),
    CONSTRAINT FK_TeamMap_1 FOREIGN KEY
    (
        Team
    )
    REFERENCES Auth4c.Team
    (
        Team
    ),
    CONSTRAINT FK_TeamMap_2 FOREIGN KEY
    (
        Domain
    )
    References Auth4c.Domain
    (
        Domain
    )
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE Auth4c.TeamProductRole
(
    Team INT NOT NULL,
    Product INT NOT NULL,
    Role INT NOT NULL,
    Status TINYINT NOT NULL,
    CONSTRAINT PK_TeamProductRole PRIMARY KEY
    (
        Team,
        Product,
        Role
    ),
    CONSTRAINT FK_TeamProductRole_1 FOREIGN KEY
    (
        Team
    )
    REFERENCES Auth4c.Team
    (
        Team
    ),
    CONSTRAINT FK_TeamProductRole_2 FOREIGN KEY
    (
        Product,
        Role
    )
    REFERENCES Auth4c.ProductRole
    (
        Product,
        Role
    )
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE Auth4c.TeamProductPermission
(
    Team INT NOT NULL,
    Product INT NOT NULL,
    Permission INT NOT NULL,
    Status TINYINT NOT NULL,
    CONSTRAINT PK_TeamProductPermission PRIMARY KEY
    (
        Team,
        Product,
        Permission
    ),
    CONSTRAINT FK_TeamProductPermission_1 FOREIGN KEY
    (
        Team
    )
    REFERENCES Auth4c.Team
    (
        Team
    ),
    CONSTRAINT FK_TeamProductPermission_2 FOREIGN KEY
    (
        Product,
        Permission
    )
    REFERENCES Auth4c.ProductPermission
    (
        Product,
        Permission
    )
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE Auth4c.User
(
    Domain VARCHAR(32) NOT NULL,
    UserId VARCHAR(32) NOT NULL,
    Name VARCHAR(64),
    AuthenticationToken VARCHAR(128),
    Contact VARCHAR(128),
    Status CHAR(1) NOT NULL,
    BadLoginCount INT,
    CONSTRAINT PK_User PRIMARY KEY
    (
        Domain,
        UserId
    ),
    CONSTRAINT FK_User_1 FOREIGN KEY
    (
        Domain
    )
    REFERENCES Auth4c.Domain
    (
        Domain
    )
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE Auth4c.DBProfile
(
    PName VARCHAR(16) NOT NULL,
    PValue VARCHAR(32) NOT NULL,
    CONSTRAINT PK_DBProfile PRIMARY KEY
    (
        PName
    )
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE Auth4c.UserTeam
(
    Domain VARCHAR(32) NOT NULL,
    UserId VARCHAR(32) NOT NULL,
    Team INT NOT NULL,
    IsLead TINYINT NOT NULL,
    CONSTRAINT PK_UserTeam PRIMARY KEY
    (
        Domain,
        UserId,
        Team
    ),
    CONSTRAINT FK_UserTeam_1 FOREIGN KEY
    (
        Domain,
        UserId
    )
    REFERENCES Auth4c.User
    (
        Domain,
        UserId
    ),
    CONSTRAINT FK_UserTeam_2 FOREIGN KEY
    (
        Team
    )
    REFERENCES Auth4c.Team
    (
        Team
    )
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE Auth4c.UserProductRole
(
    Domain VARCHAR(32) NOT NULL,
    UserId VARCHAR(32) NOT NULL,
    Product INT NOT NULL,
    Role INT NOT NULL,
    Status TINYINT NOT NULL,
    CONSTRAINT PK_UserProductRole PRIMARY KEY
    (
        Domain,
        UserId,
        Product,
        Role
    ),
    CONSTRAINT FK_UserProductRole_1 FOREIGN KEY
    (
        Domain,
        UserId
    )
    REFERENCES Auth4c.User
    (
        Domain,
        UserId
    ),
    CONSTRAINT FK_UserProductRole_2 FOREIGN KEY
    (
        Product,
        Role
    )
    REFERENCES Auth4c.ProductRole
    (
        Product,
        Role
    )
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE Auth4c.UserProductPermission
(
    Domain VARCHAR(32) NOT NULL,
    UserId VARCHAR(32) NOT NULL,
    Product INT NOT NULL,
    Permission INT NOT NULL,
    Status TINYINT NOT NULL,
    CONSTRAINT PK_UserProductPermission PRIMARY KEY
    (
        Domain,
        UserId,
        Product,
        Permission
    ),
    CONSTRAINT FK_UserProductPermission_1 FOREIGN KEY
    (
        Domain,
        UserId
    )
    REFERENCES Auth4c.User
    (
        Domain,
        UserId
    ),
    CONSTRAINT FK_UserProductPermission_2 FOREIGN KEY
    (
        Product,
        Permission
    )
    REFERENCES Auth4c.ProductPermission
    (
        Product,
        Permission
    )
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE Auth4c.AuthenticationLibraryParam
(
    AuthenticationLibrary INT NOT NULL,
    Param VARCHAR(16) NOT NULL,
    Value VARCHAR(248) NOT NULL,
    CONSTRAINT PK_AuthenticationLibraryParam PRIMARY KEY
    (
        AuthenticationLibrary,
        Param
    ),
    CONSTRAINT FK_AuthenticationLibraryParam_1 FOREIGN KEY
    (
        AuthenticationLibrary
    )
    REFERENCES Auth4c.AuthenticationLibrary
    (
        AuthenticationLibrary
    )
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE Auth4c.ProductParam
(
    Profile VARCHAR(32) NOT NULL,
    Product INT NOT NULL,
    Param VARCHAR(32) NOT NULL,
    Value VARCHAR(248) NOT NULL,
    CONSTRAINT PK_ProductParam PRIMARY KEY
    (
        Profile,
        Product,
        Param
    ),
    CONSTRAINT FK_ProductParam_1 FOREIGN KEY
    (
        Product
    )
    REFERENCES Auth4c.Product
    (
        Product
    )
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE Auth4c.AuthenticatorParam
(
    Domain VARCHAR(32) NOT NULL,
    Param VARCHAR(16) NOT NULL,
    Value VARCHAR(248) NOT NULL,
    CONSTRAINT PK_AuthenticatorParam PRIMARY KEY
    (
        Domain,
        Param
    ),
    CONSTRAINT FK_AuthenticatorParam_1 FOREIGN KEY
    (
        Domain
    )
    REFERENCES Auth4c.Domain
    (
        Domain
    )
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE Auth4c.CustomerParam
(
    Customer VARCHAR(8) NOT NULL,
    Param VARCHAR(16) NOT NULL,
    Value VARCHAR(248) NOT NULL,
    CONSTRAINT PK_CustomerParam PRIMARY KEY
    (
        Customer,
        Param
    ),
    CONSTRAINT FK_CustomerParam_1 FOREIGN KEY
    (
        Customer
    )
    REFERENCES Auth4c.Customer
    (
        Customer
    )
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

GRANT ALL ON Auth4c.* TO auth4cd@localhost IDENTIFIED BY '*47762A008EC0EACDF6E813E383B140D125045B45';

INSERT INTO Auth4c.Platform
VALUES (
         'LNX',
         'GNU/Linux'
       );

INSERT INTO Auth4c.Platform
VALUES (
         'WIN',
         'Windows'
       );

INSERT INTO Auth4c.AuthenticationLibrary
VALUES (
         0,
         'Auth4c Native',
         'P',
         'Y'
       );

INSERT INTO Auth4c.AuthenticationLibrary
VALUES (
         1,
         'MySQL',
         'P',
         'N'
       );

INSERT INTO Auth4c.AuthenticationLibrary
VALUES (
         2,
         'LDAP',
         'C',
         'N'
       );

INSERT INTO Auth4c.AuthenticationLibrary
VALUES (
         3,
         'Active Directory',
         'C',
         'N'
       );

INSERT INTO Auth4c.SharedObject
VALUES (
         'LNX',
         0,
         'libAuth4cAuth4c.so.5'
       );

INSERT INTO Auth4c.SharedObject
VALUES (
         'WIN',
         0,
         'Auth4cAuth4c.dll'
       );

INSERT INTO Auth4c.SharedObject
VALUES (
         'LNX',1,'libAuth4cMySQL.so.5.0'
       );
INSERT INTO Auth4c.SharedObject
VALUES (
         'WIN',1,'Auth4cMySQLd.dll'
       );
INSERT INTO Auth4c.SharedObject
VALUES (
         'LNX',2,'libAuth4cLDAP.so.5.0'
       );
INSERT INTO Auth4c.SharedObject
VALUES (
         'WIN',2,'Auth4cLDAPd.dll'
       );
INSERT INTO Auth4c.SharedObject
VALUES (
         'LNX',3,'libAuth4cAD.so.5.0'
       );
INSERT INTO Auth4c.SharedObject
VALUES (
         'WIN',3,'Auth4cADd.dll'
       );

INSERT INTO Auth4c.Customer
VALUES (
         'root',
         'Root'
       );

INSERT INTO Auth4c.Domain
VALUES (
         'root',
         'Root',
         'root',
         0,
         'Y'
       );

INSERT INTO Auth4c.AuthenticatorParam
VALUES (
         'root',
         'host',
         'localhost'
       );

INSERT INTO Auth4c.AuthenticatorParam
VALUES (
         'root',
         'database',
         'Auth4c'
       );

INSERT INTO Auth4c.AuthenticatorParam
VALUES (
         'root',
         'userid',
         'auth4cd'
       );

INSERT INTO Auth4c.AuthenticatorParam
VALUES (
         'root',
         'password',
         '*47762A008EC0EACDF6E813E383B140D125045B45'
       );

INSERT INTO Auth4c.Team
VALUES (
         0,
         'root',
         'Root'
       );

INSERT INTO Auth4c.User
VALUES (
         'root',
         'root',
         'Root',
         PASSWORD( 'root' ),
         '',
         'Y',
         NULL
       );

INSERT INTO Auth4c.UserTeam
VALUES (
         'root',
         'root',
         0,
         1
       );

INSERT INTO Auth4c.Product
VALUES (
         0,
         'Auth4c'
       );

INSERT INTO Auth4c.Profile
VALUES (
         'Production',
         'Y'
       );

INSERT INTO Auth4c.Profile
VALUES (
         'Testing',
         'N'
       );

INSERT INTO Auth4c.ProductParam
VALUES (
         'Production',
         0,
         'XConnect',
         CONCAT( 'host=', @@hostname, ';database=Auth4c;userid=auth4cd;password=*47762A008EC0EACDF6E813E383B140D125045B45' )
       );

INSERT INTO Auth4c.ProductPermission
VALUES (
         0,
         1,
         'Maintain Plugins',
         0
       );

INSERT INTO Auth4c.ProductPermission
VALUES (
         0,
         2,
         'Maintain Authenticators',
         0
       );

INSERT INTO Auth4c.ProductPermission
VALUES (
         0,
         3,
         'Maintain Products',
         0
       );

INSERT INTO Auth4c.ProductPermission
VALUES (
         0,
         4,
         'Administer Customers',
         0
       );

INSERT INTO Auth4c.ProductPermission
VALUES (
         0,
         5,
         'Administer Domains',
         0
       );

INSERT INTO Auth4c.ProductPermission
VALUES (
         0,
         6,
         'Administer Teams',
         0
       );

INSERT INTO Auth4c.ProductPermission
VALUES (
         0,
         7,
         'Administer Users',
         0
       );

INSERT INTO Auth4c.ProductRole
VALUES (
         0,
         1,
         'Maintainer',
         0
       );

INSERT INTO Auth4c.ProductRole
VALUES (
         0,
         2,
         'Administrator',
         0
       );

INSERT INTO Auth4c.ProductRolePermission
VALUES (
         0,
         1,
         1,
         1
       );

INSERT INTO Auth4c.ProductRolePermission
VALUES (
         0,
         1,
         2,
         1
       );

INSERT INTO Auth4c.ProductRolePermission
VALUES (
         0,
         1,
         3,
         1
       );

INSERT INTO Auth4c.ProductRolePermission
VALUES (
         0,
         2,
         4,
         1
       );

INSERT INTO Auth4c.ProductRolePermission
VALUES (
         0,
         2,
         5,
         1
       );

INSERT INTO Auth4c.ProductRolePermission
VALUES (
         0,
         2,
         6,
         1
       );

INSERT INTO Auth4c.ProductRolePermission
VALUES (
         0,
         2,
         7,
         1
       );

INSERT INTO Auth4c.TeamProductRole
VALUES (
         0,
         0,
         1,
         1
       );

INSERT INTO Auth4c.TeamProductRole
VALUES (
         0,
         0,
         2,
         1
       );

